summaryrefslogtreecommitdiff
path: root/src/core/wee-input.c
diff options
context:
space:
mode:
authorSebastien Helleu <flashcode@flashtux.org>2012-12-13 18:51:44 +0100
committerSebastien Helleu <flashcode@flashtux.org>2012-12-13 18:51:44 +0100
commit7d34812f1cd091b70395808381469c6c1f5c659a (patch)
tree8dd82177eaad95dc216bf1b68926b8398440a198 /src/core/wee-input.c
parent9db5682186de96b1deeb48e76887df7c74e77036 (diff)
downloadweechat-7d34812f1cd091b70395808381469c6c1f5c659a.zip
core: reformat comments for functions
Diffstat (limited to 'src/core/wee-input.c')
-rw-r--r--src/core/wee-input.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/core/wee-input.c b/src/core/wee-input.c
index 869568916..15c85a618 100644
--- a/src/core/wee-input.c
+++ b/src/core/wee-input.c
@@ -40,7 +40,7 @@
/*
- * input_exec_data: send data to buffer input callback
+ * Sends data to buffer input callback.
*/
void
@@ -60,7 +60,7 @@ input_exec_data (struct t_gui_buffer *buffer, const char *data)
}
/*
- * input_exec_command: execute a command (WeeChat internal or a plugin command)
+ * Executes a command.
*/
void
@@ -114,9 +114,9 @@ input_exec_command (struct t_gui_buffer *buffer,
break;
case 1: /* command hooked, OK (executed) */
break;
- case -2: /* command is ambigous (exists for other plugins) */
+ case -2: /* command is ambiguous (exists for other plugins) */
gui_chat_printf (NULL,
- _("%sError: ambigous command \"%s\": it exists "
+ _("%sError: ambiguous command \"%s\": it exists "
"in many plugins and not in \"%s\" plugin"),
gui_chat_prefix[GUI_CHAT_PREFIX_ERROR],
command + 1,
@@ -152,7 +152,7 @@ input_exec_command (struct t_gui_buffer *buffer,
}
/*
- * input_data: read user input and send data to buffer callback
+ * Reads user input and sends data to buffer's callback.
*/
void